package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallShopConfig;

/**
 * 配置信息设置Mapper接口
 * 
 * @author ruoyi
 * @date 2021-11-25
 */
public interface MallShopConfigMapper 
{
    /**
     * 查询配置信息设置
     * 
     * @param id 配置信息设置主键
     * @return 配置信息设置
     */
    public MallShopConfig selectMallShopConfigById(Long id);

    /**
     * 查询配置信息设置列表
     * 
     * @param mallShopConfig 配置信息设置
     * @return 配置信息设置集合
     */
    public List<MallShopConfig> selectMallShopConfigList(MallShopConfig mallShopConfig);

    /**
     * 新增配置信息设置
     * 
     * @param mallShopConfig 配置信息设置
     * @return 结果
     */
    public int insertMallShopConfig(MallShopConfig mallShopConfig);

    /**
     * 修改配置信息设置
     * 
     * @param mallShopConfig 配置信息设置
     * @return 结果
     */
    public int updateMallShopConfig(MallShopConfig mallShopConfig);

    /**
     * 删除配置信息设置
     * 
     * @param id 配置信息设置主键
     * @return 结果
     */
    public int deleteMallShopConfigById(Long id);

    /**
     * 批量删除配置信息设置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallShopConfigByIds(Long[] ids);
}
