package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallShopConfig;
import com.ruoyi.mall.service.IMallShopConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 配置信息设置Controller
 * 
 * @author ruoyi
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallShopConfig")
public class MallShopConfigController extends BaseController
{
    @Autowired
    private IMallShopConfigService mallShopConfigService;

    /**
     * 查询配置信息设置列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallShopConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallShopConfig mallShopConfig)
    {
        startPage();
        List<MallShopConfig> list = mallShopConfigService.selectMallShopConfigList(mallShopConfig);
        return getDataTable(list);
    }

    /**
     * 导出配置信息设置列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallShopConfig:export')")
    @Log(title = "配置信息设置", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallShopConfig mallShopConfig)
    {
        List<MallShopConfig> list = mallShopConfigService.selectMallShopConfigList(mallShopConfig);
        ExcelUtil<MallShopConfig> util = new ExcelUtil<MallShopConfig>(MallShopConfig.class);
        return util.exportExcel(list, "配置信息设置数据");
    }

    /**
     * 获取配置信息设置详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallShopConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallShopConfigService.selectMallShopConfigById(id));
    }

    /**
     * 新增配置信息设置
     */
    @PreAuthorize("@ss.hasPermi('mall:mallShopConfig:add')")
    @Log(title = "配置信息设置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallShopConfig mallShopConfig)
    {
        return toAjax(mallShopConfigService.insertMallShopConfig(mallShopConfig));
    }

    /**
     * 修改配置信息设置
     */
    @PreAuthorize("@ss.hasPermi('mall:mallShopConfig:edit')")
    @Log(title = "配置信息设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallShopConfig mallShopConfig)
    {
        return toAjax(mallShopConfigService.updateMallShopConfig(mallShopConfig));
    }

    /**
     * 删除配置信息设置
     */
    @PreAuthorize("@ss.hasPermi('mall:mallShopConfig:remove')")
    @Log(title = "配置信息设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallShopConfigService.deleteMallShopConfigByIds(ids));
    }
}
